@@ -3,7 +3,7 @@ We can use grok.AddForm to render an add form for objects:
 
   >>> getRootFolder()["zoo"] = Zoo()
 
-  >>> from zope.app.wsgi.testlayer import Browser
+  >>> from zope.testbrowser.wsgi import Browser
   >>> browser = Browser()
   >>> browser.handleErrors = False
 
@@ -11,7 +11,7 @@ We can use grok.AddForm to render an add form for objects:
   >>> browser.getControl(name="form.name").value = "Manfred the Mammoth"
   >>> browser.getControl(name="form.size").value = "Really big"
   >>> browser.getControl("Add entry").click()
-  >>> print browser.contents
+  >>> print(browser.contents)
   Hi, my name is Manfred the Mammoth, and I\'m "Really big"
 
 Instead of calling an object constructor with the form data, we can
@@ -21,13 +21,13 @@ also use the ``applyData`` method to store the data on the object.
   >>> browser.getControl(name="form.name").value = "Ellie the Mammoth"
   >>> browser.getControl(name="form.size").value = "Really small"
   >>> browser.getControl("Add entry").click()
-  >>> print browser.contents
+  >>> print(browser.contents)
   Hi, my name is Ellie the Mammoth, and I\'m "Really small"
 
 """
 import grokcore.formlib as grok
 from zope import schema
-from zope.interface import Interface, implements
+from zope.interface import Interface, implementer
 from zope.container.btree import BTreeContainer
 from zope.container.contained import Contained
 from zope.container.interfaces import IContainer
@@ -39,8 +39,9 @@ class IMammoth(Interface):
     name = schema.TextLine(title=u"Name")
     size = schema.TextLine(title=u"Size", default=u"Quite normal")
 
+
+@implementer(IMammoth)
 class Mammoth(Contained, grok.testing.Model):
-    implements(IMammoth)
     grok.testing.protect_get(grok.Public, 'name', 'size')
     grok.testing.protect_set(grok.Public, 'name', 'size')
 
@@ -50,6 +51,7 @@ class Mammoth(Contained, grok.testing.Model):
 
 class Index(grok.View):
     grok.context(Mammoth)
+
     def render(self):
         return 'Hi, my name is %s, and I\'m "%s"' % (self.context.name,
                                                      self.context.size)
